@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 07.08.2017: Added audit trail.
 # 18.09.2016: Now retains information in 'File.Name' and 'File.Time' when add markers.
 # 18.09.2016: Fixed attribute kit not save correct.
 # 06.09.2016: Added check for conflicting options filter.alleles and add.missing.loci.
@@ -24,9 +25,6 @@
 # 06.06.2013: Fixed bug in checking for 'fat' data.
 # 03.06.2013: Fixed bug discarding NA loci when add.missing.loci=TRUE.
 # 28.04.2013: Fixed "NA" bug (NA worked but not "NA").
-# 15.04.2013: Option 'ignore.case'.
-# 12.04.2013: Options 'keep.na' and 'add.missing.loci' implemented as 'slow' method. 
-# 11.04.2013: Fixed bug when more than one reference sample.
 
 #' @title Filter Profile
 #'
@@ -57,9 +55,9 @@
 #' @param sex.rm logical TRUE removes sex markers defined by 'kit'.
 #' @param qs.rm logical TRUE removes quality sensors defined by 'kit'.
 #' @param kit character string defining the kit used.
-#' If NULL autodetection will be attempted.
+#' If NULL automatic detection will be attempted.
 #' @param filter.allele logical TRUE filter known alleles. FALSE increase the
-#' performance if only sex markers or quality sensors shold be removed.
+#' performance if only sex markers or quality sensors should be removed.
 #' @param debug logical indicating printing debug information.
 #' 
 #' 
@@ -715,20 +713,9 @@ filterProfile <- function(data, ref=NULL, add.missing.loci=FALSE, keep.na=FALSE,
   
   # Add attributes to result.
   attr(res, which="kit") <- kit
-  attr(res, which="filterProfile, strvalidator") <- as.character(utils::packageVersion("strvalidator"))
-  attr(res, which="filterProfile, call") <- match.call()
-  attr(res, which="filterProfile, date") <- date()
-  attr(res, which="filterProfile, data") <- attr_data
-  attr(res, which="filterProfile, ref") <- attr_ref
-  attr(res, which="filterProfile, add.missing.loci") <- add.missing.loci
-  attr(res, which="filterProfile, keep.na") <- keep.na
-  attr(res, which="filterProfile, ignore.case") <- ignore.case
-  attr(res, which="filterProfile, exact") <- exact
-  attr(res, which="filterProfile, word") <- word
-  attr(res, which="filterProfile, invert") <- invert
-  attr(res, which="filterProfile, sex.rm") <- sex.rm
-  attr(res, which="filterProfile, qs.rm") <- qs.rm
-  attr(res, which="filterProfile, filter.allele") <- filter.allele
+  
+  # Update audit trail.
+  res <- auditTrail(obj = res, f.call = match.call(), package = "strvalidator")
   
   # RETURN --------------------------------------------------------------------
   
