@@ -4,6 +4,10 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 13.07.2017: Fixed issue with button handlers.
+# 13.07.2017: Fixed narrow dropdown with hidden argument ellipsize = "none".
+# 07.07.2017: Replaced 'droplist' with 'gcombobox'.
+# 07.07.2017: Removed argument 'border' for 'gbutton'.
 # 06.01.2016: Fixed theme methods not found and added more themes.
 # 22.12.2015: First version.
 
@@ -14,9 +18,9 @@
 #'
 #' @details Select data to plot in the drop-down menu. 
 #' Automatic plot titles can be replaced by custom titles.
-#' A name for the result is automatiaclly suggested.
+#' A name for the result is automatically suggested.
 #' The resulting plot can be saved as either a plot object or as an image.
-#' @param env environment in wich to search for data frames.
+#' @param env environment in which to search for data frames.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' @param parent widget to get focus when finished.
@@ -93,12 +97,13 @@ plotRatio_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   glabel(text="Select dataset:", container=f0)
 
-  dataset_drp <- gdroplist(items=c("<Select dataset>",
+  dataset_drp <- gcombobox(items=c("<Select dataset>",
                                    listObjects(env=env,
                                                obj.class="data.frame")), 
                            selected = 1,
                            editable = FALSE,
-                           container = f0) 
+                           container = f0,
+                           ellipsize = "none") 
   
   f0_samples_lbl <- glabel(text=" (0 samples)", container=f0)
   
@@ -185,9 +190,10 @@ plotRatio_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   items_theme <- c("theme_grey()","theme_bw()","theme_linedraw()",
                    "theme_light()","theme_dark()","theme_minimal()",
                    "theme_classic()","theme_void()")
-  f1g2[1,2] <- f1_theme_drp <- gdroplist(items = items_theme,
+  f1g2[1,2] <- f1_theme_drp <- gcombobox(items = items_theme,
                                          selected = 1,
-                                         container = f1g2)
+                                         container = f1g2,
+                                         ellipsize = "none")
   
   # FRAME 7 ###################################################################
   
@@ -197,14 +203,10 @@ plotRatio_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   grid7 <- glayout(container = f7)
   
-  grid7[1,1] <- plot_browse_btn <- gbutton(text="Browse",
-                                           border=TRUE,
-                                           container=grid7)
+  grid7[1,1] <- plot_browse_btn <- gbutton(text="Browse", container=grid7)
   tooltip(plot_browse_btn) <- "Activate the console window and use Enter key to change plot"
   
-  grid7[1,2] <- plot_all_btn <- gbutton(text="Plot",
-                                           border=TRUE,
-                                           container=grid7) 
+  grid7[1,2] <- plot_all_btn <- gbutton(text="Plot", container=grid7) 
   tooltip(plot_all_btn) <- "Plot all data in one plot, by group if available"
   
   addHandlerChanged(plot_browse_btn, handler = function(h, ...) {
@@ -234,20 +236,18 @@ plotRatio_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
   
   f5_save_edt <- gedit(text="", container=f5)
   
-  f5_save_btn <- gbutton(text = "Save as object",
-                         border=TRUE,
-                         container = f5)
+  f5_save_btn <- gbutton(text = "Save as object", container = f5)
   
-  f5_ggsave_btn <- gbutton(text = "Save as image",
-                               border=TRUE,
-                               container = f5) 
+  f5_ggsave_btn <- gbutton(text = "Save as image", container = f5) 
   
-  addHandlerChanged(f5_save_btn, handler = function(h, ...) {
+  addHandlerClicked(f5_save_btn, handler = function(h, ...) {
     
     val_name <- svalue(f5_save_edt)
     
     # Change button.
+    blockHandlers(f5_save_btn)
     svalue(f5_save_btn) <- "Processing..."
+    unblockHandlers(f5_save_btn)
     enabled(f5_save_btn) <- FALSE
     
     # Save data.
@@ -255,7 +255,9 @@ plotRatio_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
                parent=w, env=env, debug=debug)
     
     # Change button.
+    blockHandlers(f5_save_btn)
     svalue(f5_save_btn) <- "Object saved"
+    unblockHandlers(f5_save_btn)
     
   } )
   
@@ -433,7 +435,7 @@ plotRatio_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=
       
     } else {
       
-      gmessage(message="Data frame is NULL or NA!",
+      gmessage(msg="Data frame is NULL or NA!",
                title="Error",
                icon = "error")      
       
